==> apache-camel-3.4.0-src.zip: apache-camel-3.4.0/core/camel-core/src/test/java/org/apache/camel/component/file/FileConsumerAutoCreateDirectoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.file;

import java.io.File;
import java.io.FileNotFoundException;

import org.apache.camel.Consumer;
import org.apache.camel.ContextTestSupport;
import org.apache.camel.Endpoint;
import org.apache.camel.Exchange;
import org.apache.camel.Processor;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.*;

public class FileConsumerAutoCreateDirectoryTest extends ContextTestSupport {

    @Test
    public void testCreateDirectory() throws Exception {
        deleteDirectory("target/data/file/foo");

        Endpoint endpoint = context.getEndpoint("file://target/data/file/foo");
        Consumer consumer = endpoint.createConsumer(new Processor() {
            public void process(Exchange exchange) throws Exception {
                // noop
            }
        });

        consumer.start();
        consumer.stop();

        // the directory should now exists
        File dir = new File("target/data/file/foo");
        assertTrue(dir.exists(), "Directory should be created");
        assertTrue(dir.isDirectory(), "Directory should be a directory");
    }

    @Test
    public void testCreateAbsoluteDirectory() throws Exception {
        deleteDirectory("target/data/file/foo");
        // use current dir as base as absolute path
        String base = new File("").getAbsolutePath() + "/target/data/file/foo";

        Endpoint endpoint = context.getEndpoint("file://" + base);
        Consumer consumer = endpoint.createConsumer(new Processor() {
            public void process(Exchange exchange) throws Exception {
                // noop
            }
        });

        consumer.start();
        consumer.stop();

        // the directory should now exists
        File dir = new File(base);
        assertTrue(dir.exists(), "Directory should be created");
        assertTrue(dir.isDirectory(), "Directory should be a directory");
    }

    @Test
    public void testDoNotCreateDirectory() throws Exception {
        deleteDirectory("target/data/file/foo");

        Endpoint endpoint = context.getEndpoint("file://target/data/file/foo?autoCreate=false");
        Consumer consumer = endpoint.createConsumer(new Processor() {
            public void process(Exchange exchange) throws Exception {
                // noop
            }
        });

        consumer.start();
        consumer.stop();

        // the directory should NOT exists
        File dir = new File("target/data/file/foo");
        assertFalse(dir.exists(), "Directory should NOT be created");
    }

    @Test
    public void testAutoCreateDirectoryWithDot() throws Exception {
        deleteDirectory("target/data/file/foo.bar");

        Endpoint endpoint = context.getEndpoint("file://target/data/file/foo.bar?autoCreate=true");
        Consumer consumer = endpoint.createConsumer(new Processor() {
            public void process(Exchange exchange) throws Exception {
                // noop
            }
        });

        consumer.start();
        consumer.stop();

        // the directory should exist
        File dir = new File("target/data/file/foo.bar");
        assertTrue(dir.exists(), "Directory should be created");
        assertTrue(dir.isDirectory(), "Directory should be a directory");
    }

    @Test
    public void testStartingDirectoryMustExistDirectory() throws Exception {
        deleteDirectory("target/data/file/foo");

        Endpoint endpoint = context.getEndpoint("file://target/data/file/foo?autoCreate=false&startingDirectoryMustExist=true");
        try {
            endpoint.createConsumer(new Processor() {
                public void process(Exchange exchange) throws Exception {
                    // noop
                }
            });
            fail("Should have thrown an exception");
        } catch (FileNotFoundException e) {
            assertTrue(e.getMessage().startsWith("Starting directory does not exist"));
        }

        // the directory should NOT exists
        File dir = new File("target/data/file/foo");
        assertFalse(dir.exists(), "Directory should NOT be created");
    }

}

==> apache-camel-4.0.4-src.zip: apache-camel-4.0.4/core/camel-core/src/test/java/org/apache/camel/component/file/FileConsumerAutoCreateDirectoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.file;

import java.io.FileNotFoundException;
import java.nio.file.Files;

import org.apache.camel.Consumer;
import org.apache.camel.ContextTestSupport;
import org.apache.camel.Endpoint;
import org.apache.camel.Exchange;
import org.apache.camel.Processor;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;
import static org.junit.jupiter.api.Assertions.fail;

public class FileConsumerAutoCreateDirectoryTest extends ContextTestSupport {

    @Test
    public void testCreateDirectory() throws Exception {
        Endpoint endpoint = context.getEndpoint(fileUri("foo"));
        Consumer consumer = endpoint.createConsumer(new Processor() {
            public void process(Exchange exchange) throws Exception {
                // noop
            }
        });

        consumer.start();
        consumer.stop();

        // the directory should now exists
        assertTrue(Files.exists(testDirectory("foo")), "Directory should be created");
        assertTrue(Files.isDirectory(testDirectory("foo")), "Directory should be a directory");
    }

    @Test
    public void testCreateAbsoluteDirectory() throws Exception {
        // use current dir as base as absolute path
        String base = testDirectory("foo").toAbsolutePath().toString();

        Endpoint endpoint = context.getEndpoint("file://" + base);
        Consumer consumer = endpoint.createConsumer(new Processor() {
            public void process(Exchange exchange) throws Exception {
                // noop
            }
        });

        consumer.start();
        consumer.stop();

        // the directory should now exists
        assertTrue(Files.exists(testDirectory("foo")), "Directory should be created");
        assertTrue(Files.isDirectory(testDirectory("foo")), "Directory should be a directory");
    }

    @Test
    public void testDoNotCreateDirectory() throws Exception {
        Endpoint endpoint = context.getEndpoint(fileUri("foo?autoCreate=false"));
        Consumer consumer = endpoint.createConsumer(new Processor() {
            public void process(Exchange exchange) throws Exception {
                // noop
            }
        });

        consumer.start();
        consumer.stop();

        // the directory should NOT exists
        assertFalse(Files.exists(testDirectory("foo")), "Directory should NOT be created");
    }

    @Test
    public void testAutoCreateDirectoryWithDot() throws Exception {
        Endpoint endpoint = context.getEndpoint(fileUri("foo.bar?autoCreate=true"));
        Consumer consumer = endpoint.createConsumer(new Processor() {
            public void process(Exchange exchange) throws Exception {
                // noop
            }
        });

        consumer.start();
        consumer.stop();

        // the directory should exist
        assertTrue(Files.exists(testDirectory("foo.bar")), "Directory should be created");
        assertTrue(Files.isDirectory(testDirectory("foo.bar")), "Directory should be a directory");
    }

    @Test
    public void testStartingDirectoryMustExistDirectory() throws Exception {
        Endpoint endpoint = context.getEndpoint(fileUri("foo?autoCreate=false&startingDirectoryMustExist=true"));
        try {
            endpoint.createConsumer(new Processor() {
                public void process(Exchange exchange) throws Exception {
                    // noop
                }
            });
            fail("Should have thrown an exception");
        } catch (FileNotFoundException e) {
            assertTrue(e.getMessage().startsWith("Starting directory does not exist"));
        }

        // the directory should NOT exists
        assertFalse(Files.exists(testDirectory("foo")), "Directory should NOT be created");
    }

}
